=================
pip-compile-multi
=================

.. image:: https://badge.fury.io/py/pip-compile-multi.png
    :target: http://badge.fury.io/py/pip-compile-multi

.. image:: https://travis-ci.org/peterdemin/pip-compile-multi.svg?branch=master
    :target: https://travis-ci.org/peterdemin/pip-compile-multi

.. image:: https://ci.appveyor.com/api/projects/status/1spvqh9hlqtv2a81?svg=true
    :target: https://ci.appveyor.com/project/peterdemin/pip-compile-multi

.. image:: https://img.shields.io/pypi/pyversions/pip-compile-multi.svg
    :target: https://pypi.python.org/pypi/pip-compile-multi

`Docs <https://pip-compile-multi.readthedocs.io/en/latest/>`_

Compile multiple requirements files to lock dependency versions.

Install
-------

.. code-block:: shell

    pip install pip-compile-multi

Run
----

.. code-block:: shell

    pip-compile-multi


Trusted by
----------

|nih| |uber| |mozilla|


Read the Docs
-------------

* `Why use pip-compile-multi <https://pip-compile-multi.readthedocs.io/en/latest/why.html>`_
* `How to start using pip-compile-multi <https://pip-compile-multi.readthedocs.io/en/latest/migration.html>`_
* `List of features <https://pip-compile-multi.readthedocs.io/en/latest/features.html>`_

.. |nih| image:: docs/NIH_logo.svg
   :width: 200 px
   :height: 200 px

.. |uber| image:: docs/Uber_Logo_Black_RGB.svg
   :width: 200 px
   :height: 200 px

.. |mozilla| image:: docs/moz-logo-bw-rgb.svg
   :width: 200 px
   :height: 200 px

